# controlm-client
Provides access to BMC Control-M Services

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 9.18.3
- Package version: 9.0.19
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import controlm_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import controlm_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import controlm_client
from controlm_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: Bearer
configuration = controlm_client.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = controlm_client.BuildApi(controlm_client.ApiClient(configuration))
definitions_file = '/path/to/file.txt' # file | A file that contains definitions to be compiled. Can be either a JSON definition file, or a zip file that contains multiple JSON definition files.
deploy_descriptor_file = '/path/to/file.txt' # file | Deploy Descriptor JSON file. (optional)

try:
    # Compile definitions file to check its validity
    api_response = api_instance.build_file(definitions_file, deploy_descriptor_file=deploy_descriptor_file)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling BuildApi->build_file: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BuildApi* | [**build_file**](docs/BuildApi.md#build_file) | **POST** /build | Compile definitions file to check its validity
*ConfigApi* | [**add_agent**](docs/ConfigApi.md#add_agent) | **POST** /config/server/{ctm}/agent | add agent to Control-M Server
*ConfigApi* | [**add_host_to_hostgroup**](docs/ConfigApi.md#add_host_to_hostgroup) | **POST** /config/server/{ctm}/hostgroup/{hostgroup}/agent | add agent to hostgroup
*ConfigApi* | [**add_remote_host**](docs/ConfigApi.md#add_remote_host) | **POST** /config/server/{ctm}/remotehost | add remote host to Control-M Server
*ConfigApi* | [**add_role**](docs/ConfigApi.md#add_role) | **POST** /config/authorization/role | Add Authorization Role
*ConfigApi* | [**add_role_to_ldap_group**](docs/ConfigApi.md#add_role_to_ldap_group) | **POST** /config/authorization/ldap/{ldapgroup}/role/{role} | Add a role to LDAP group
*ConfigApi* | [**add_role_to_user**](docs/ConfigApi.md#add_role_to_user) | **POST** /config/authorization/user/{user}/role/{role} | Add a role to user
*ConfigApi* | [**add_secret**](docs/ConfigApi.md#add_secret) | **POST** /config/secret | Add a new secret
*ConfigApi* | [**add_server**](docs/ConfigApi.md#add_server) | **POST** /config/server | add Control-M server to the system
*ConfigApi* | [**add_user**](docs/ConfigApi.md#add_user) | **POST** /config/authorization/user | Add user
*ConfigApi* | [**authorize_ssh_known_remotehost**](docs/ConfigApi.md#authorize_ssh_known_remotehost) | **POST** /config/server/{ctm}/remotehost/{remotehost}/authorize | Authorize
*ConfigApi* | [**change_user_password**](docs/ConfigApi.md#change_user_password) | **POST** /config/user/{user}/password/adminUpdate | Change user password
*ConfigApi* | [**create_run_as_user**](docs/ConfigApi.md#create_run_as_user) | **POST** /config/server/{ctm}/runasuser | Add a new Run-as user
*ConfigApi* | [**delete_agent**](docs/ConfigApi.md#delete_agent) | **DELETE** /config/server/{ctm}/agent/{agent} | delete an agent from Control-M Server
*ConfigApi* | [**delete_authorization_role**](docs/ConfigApi.md#delete_authorization_role) | **DELETE** /config/authorization/role/{role} | Delete Authorization Role
*ConfigApi* | [**delete_host_from_group**](docs/ConfigApi.md#delete_host_from_group) | **DELETE** /config/server/{ctm}/hostgroup/{hostgroup}/agent/{host} | delete an agent from a hostgroup
*ConfigApi* | [**delete_remote_host**](docs/ConfigApi.md#delete_remote_host) | **DELETE** /config/server/{ctm}/remotehost/{remotehost} | delete a remote host from Control-M Server
*ConfigApi* | [**delete_role_from_ldap_group**](docs/ConfigApi.md#delete_role_from_ldap_group) | **DELETE** /config/authorization/ldap/{ldapgroup}/role/{role} | Delete a role from LDAP group
*ConfigApi* | [**delete_run_as_user**](docs/ConfigApi.md#delete_run_as_user) | **DELETE** /config/server/{ctm}/runasuser/{agent}/{user} | delete Run-as user
*ConfigApi* | [**delete_secret**](docs/ConfigApi.md#delete_secret) | **DELETE** /config/secret/{name} | Delete an existing secret
*ConfigApi* | [**delete_user**](docs/ConfigApi.md#delete_user) | **DELETE** /config/authorization/user/{user} | Delete user
*ConfigApi* | [**disable_agent**](docs/ConfigApi.md#disable_agent) | **POST** /config/server/{ctm}/agent/{agent}/disable | disable agent from the Control-M Server
*ConfigApi* | [**enable_agent**](docs/ConfigApi.md#enable_agent) | **POST** /config/server/{ctm}/agent/{agent}/enable | enable agent from the Control-M Server
*ConfigApi* | [**failover**](docs/ConfigApi.md#failover) | **PUT** /config/server/{ctm}/failover | Perform Manual Failover on a specified Control-M Server
*ConfigApi* | [**get_agent_parameters**](docs/ConfigApi.md#get_agent_parameters) | **GET** /config/server/{ctm}/agent/{agent}/params | get agent parameters
*ConfigApi* | [**get_agents**](docs/ConfigApi.md#get_agents) | **GET** /config/server/{ctm}/agents | get Control-M Server agents
*ConfigApi* | [**get_all_authorization_roles**](docs/ConfigApi.md#get_all_authorization_roles) | **GET** /config/authorization/roles | Get Authorization Roles
*ConfigApi* | [**get_all_roles_associated_with_ldap**](docs/ConfigApi.md#get_all_roles_associated_with_ldap) | **GET** /config/authorization/ldap/{ldapgroup}/roles | Get Authorization Roles associated with an LDAP group
*ConfigApi* | [**get_all_users**](docs/ConfigApi.md#get_all_users) | **GET** /config/authorization/users | Get users
*ConfigApi* | [**get_hostgroups**](docs/ConfigApi.md#get_hostgroups) | **GET** /config/server/{ctm}/hostgroups | get Control-M Server hostgroups
*ConfigApi* | [**get_hosts_in_group**](docs/ConfigApi.md#get_hosts_in_group) | **GET** /config/server/{ctm}/hostgroup/{hostgroup}/agents | get hostgroup agents
*ConfigApi* | [**get_remote_host_properties**](docs/ConfigApi.md#get_remote_host_properties) | **GET** /config/server/{ctm}/remotehost/{remotehost} | get a remote host configuration from Control-M Server
*ConfigApi* | [**get_remote_hosts**](docs/ConfigApi.md#get_remote_hosts) | **GET** /config/server/{ctm}/remotehosts | get Control-M Server remote hosts
*ConfigApi* | [**get_role**](docs/ConfigApi.md#get_role) | **GET** /config/authorization/role/{role} | Get Authorization Role
*ConfigApi* | [**get_role_associates**](docs/ConfigApi.md#get_role_associates) | **GET** /config/authorization/role/{role}/associates | Get all authorization entities associated with role
*ConfigApi* | [**get_run_as_user**](docs/ConfigApi.md#get_run_as_user) | **GET** /config/server/{ctm}/runasuser/{agent}/{user} | Get Run-as user
*ConfigApi* | [**get_run_as_users_list**](docs/ConfigApi.md#get_run_as_users_list) | **GET** /config/server/{ctm}/runasusers | Get Run-as user list that match the requested search criteria.
*ConfigApi* | [**get_server_parameters**](docs/ConfigApi.md#get_server_parameters) | **GET** /config/server/{ctm}/params | get Control-M Server parameters
*ConfigApi* | [**get_servers**](docs/ConfigApi.md#get_servers) | **GET** /config/servers | get all the Control-M Servers name and hostname in the system
*ConfigApi* | [**get_user**](docs/ConfigApi.md#get_user) | **GET** /config/authorization/user/{user} | Get user
*ConfigApi* | [**list_secrets**](docs/ConfigApi.md#list_secrets) | **GET** /config/secrets | Get list of secret names
*ConfigApi* | [**ping_agent**](docs/ConfigApi.md#ping_agent) | **POST** /config/server/{ctm}/agent/{agent}/ping | ping to the agent in the Control-M Server
*ConfigApi* | [**remove_controlm_server**](docs/ConfigApi.md#remove_controlm_server) | **DELETE** /config/server/{ctm} | Delete Control-M server
*ConfigApi* | [**remove_role_from_user**](docs/ConfigApi.md#remove_role_from_user) | **DELETE** /config/authorization/user/{user}/role/{role} | Remove a role from a user
*ConfigApi* | [**set_agent_parameter**](docs/ConfigApi.md#set_agent_parameter) | **POST** /config/server/{ctm}/agent/{agent}/param/{name} | set agent parameter
*ConfigApi* | [**set_system_param**](docs/ConfigApi.md#set_system_param) | **POST** /config/em/param/{name} | set value of a an em system parameter
*ConfigApi* | [**setasprimary**](docs/ConfigApi.md#setasprimary) | **PUT** /config/server/{ctm}/setasprimary | Set secondary server as Primary on a specified Control-M Server
*ConfigApi* | [**test_run_as_user**](docs/ConfigApi.md#test_run_as_user) | **POST** /config/server/{ctm}/runasuser/{agent}/{user}/test | Test existed Run-as user
*ConfigApi* | [**update_role**](docs/ConfigApi.md#update_role) | **POST** /config/authorization/role/{role} | Update Authorization Role
*ConfigApi* | [**update_run_as_user**](docs/ConfigApi.md#update_run_as_user) | **POST** /config/server/{ctm}/runasuser/{agent}/{user} | Update Run-as user
*ConfigApi* | [**update_secret**](docs/ConfigApi.md#update_secret) | **POST** /config/secret/{name} | Update an existing secret
*ConfigApi* | [**update_user**](docs/ConfigApi.md#update_user) | **POST** /config/authorization/user/{user} | Update user
*DeployApi* | [**delete_connection_profile**](docs/DeployApi.md#delete_connection_profile) | **DELETE** /deploy/connectionprofile/{ctm}/{agent}/{type}/{name} | Delete a Connection Profile
*DeployApi* | [**delete_folder**](docs/DeployApi.md#delete_folder) | **DELETE** /deploy/folder/{controlM}/{folderName} | delete a folder
*DeployApi* | [**deploy_file**](docs/DeployApi.md#deploy_file) | **POST** /deploy | Deploy definitions file
*DeployApi* | [**get_deployed_connection_profiles**](docs/DeployApi.md#get_deployed_connection_profiles) | **GET** /deploy/connectionprofiles | Get deployed folder
*DeployApi* | [**get_deployed_folders_new**](docs/DeployApi.md#get_deployed_folders_new) | **GET** /deploy/jobs | Get deployed jobs that match the search criteria.
*DeployApi* | [**transform_file**](docs/DeployApi.md#transform_file) | **POST** /deploy/transform | Transform a definitions file
*ProvisionApi* | [**cancel_upgrade_activity**](docs/ProvisionApi.md#cancel_upgrade_activity) | **POST** /provision/upgrade/{upgradeId}/cancel | Cancel upgrade activity
*ProvisionApi* | [**delete_upgrade_activity**](docs/ProvisionApi.md#delete_upgrade_activity) | **DELETE** /provision/upgrade/{upgradeId} | Delete upgrade activity status for specific upgrade id.
*ProvisionApi* | [**get_all_upgrade_activities_status**](docs/ProvisionApi.md#get_all_upgrade_activities_status) | **GET** /provision/upgrades | Get all upgrade activities status.
*ProvisionApi* | [**get_deploy_versions**](docs/ProvisionApi.md#get_deploy_versions) | **GET** /provision/upgrades/versions | Get available versions for upgrade.
*ProvisionApi* | [**get_eligible_agents_for_upgrade**](docs/ProvisionApi.md#get_eligible_agents_for_upgrade) | **GET** /provision/upgrades/agents | Get eligible agents for upgrade that match the requested search criteria.
*ProvisionApi* | [**get_images**](docs/ProvisionApi.md#get_images) | **GET** /provision/images/{os} | get list of available images for the requested OS
*ProvisionApi* | [**get_upgrade_activity_log**](docs/ProvisionApi.md#get_upgrade_activity_log) | **GET** /provision/upgrade/{upgradeId}/output | Returns log of upgrade activity.
*ProvisionApi* | [**get_upgrade_activity_status_per_upgrade_id**](docs/ProvisionApi.md#get_upgrade_activity_status_per_upgrade_id) | **GET** /provision/upgrade/{upgradeId} | Get upgrade activity status for specific upgrade id.
*ProvisionApi* | [**retry_upgrade_activity**](docs/ProvisionApi.md#retry_upgrade_activity) | **POST** /provision/upgrade/{upgradeId}/retry | Retry upgrade activity
*ProvisionApi* | [**transfer_and_install_product**](docs/ProvisionApi.md#transfer_and_install_product) | **POST** /provision/upgrade/install | Transfer and install a product on an agent
*ProvisionApi* | [**uninstall_product**](docs/ProvisionApi.md#uninstall_product) | **POST** /provision/upgrade/uninstall | Uninstall a product from an agent
*ReportingApi* | [**get_report_by_name**](docs/ReportingApi.md#get_report_by_name) | **GET** /reporting/report/{name} | Retrives a report by name.
*ReportingApi* | [**get_report_status**](docs/ReportingApi.md#get_report_status) | **GET** /reporting/status/{reportId} | Retrieves status information for a report generation request based on the report ID
*ReportingApi* | [**run_report**](docs/ReportingApi.md#run_report) | **POST** /reporting/report | Run a report
*RunApi* | [**activate_workload_policy**](docs/RunApi.md#activate_workload_policy) | **POST** /run/workloadpolicy/{policy}/activate | activate workload policy
*RunApi* | [**add_event**](docs/RunApi.md#add_event) | **POST** /run/event/{ctm} | Add a new  event.
*RunApi* | [**add_resource**](docs/RunApi.md#add_resource) | **POST** /run/resource/{ctm} | Add a new quantitative resource.
*RunApi* | [**confirm_job**](docs/RunApi.md#confirm_job) | **POST** /run/job/{jobId}/confirm | confirm a job
*RunApi* | [**deactivate_workload_policy**](docs/RunApi.md#deactivate_workload_policy) | **POST** /run/workloadpolicy/{policy}/deactivate | deactivate a workload policy
*RunApi* | [**delete_event**](docs/RunApi.md#delete_event) | **DELETE** /run/event/{ctm}/{name}/{date} | Delete a  event.
*RunApi* | [**delete_job**](docs/RunApi.md#delete_job) | **POST** /run/job/{jobId}/delete | mark job as deleted
*RunApi* | [**delete_resource**](docs/RunApi.md#delete_resource) | **DELETE** /run/resource/{ctm}/{name} | Delete a quantitative resource.
*RunApi* | [**free_job**](docs/RunApi.md#free_job) | **POST** /run/job/{jobId}/free | free an already held the job
*RunApi* | [**get_events**](docs/RunApi.md#get_events) | **GET** /run/events | Get all events records for specific search.
*RunApi* | [**get_job_log**](docs/RunApi.md#get_job_log) | **GET** /run/job/{jobId}/log | Get job&#39;s log
*RunApi* | [**get_job_output**](docs/RunApi.md#get_job_output) | **GET** /run/job/{jobId}/output | Get job output
*RunApi* | [**get_job_status**](docs/RunApi.md#get_job_status) | **GET** /run/job/{jobId}/status | Get status of a job
*RunApi* | [**get_jobs_status**](docs/RunApi.md#get_jobs_status) | **GET** /run/status/{runId} | Get status of running jobs
*RunApi* | [**get_jobs_status_by_filter**](docs/RunApi.md#get_jobs_status_by_filter) | **GET** /run/jobs/status | Get jobs that match the search criteria.
*RunApi* | [**get_resources**](docs/RunApi.md#get_resources) | **GET** /run/resources | Get all resources records matching search.
*RunApi* | [**get_workload_policies**](docs/RunApi.md#get_workload_policies) | **GET** /run/workloadpolicies | get workload policies
*RunApi* | [**hold_job**](docs/RunApi.md#hold_job) | **POST** /run/job/{jobId}/hold | hold the job so it will not start untill it is freed
*RunApi* | [**kill_job**](docs/RunApi.md#kill_job) | **POST** /run/job/{jobId}/kill | Cancel running job
*RunApi* | [**order_jobs_in_folder**](docs/RunApi.md#order_jobs_in_folder) | **POST** /run/order | Execute requested jobs in certain folder
*RunApi* | [**rerun_job**](docs/RunApi.md#rerun_job) | **POST** /run/job/{jobId}/rerun | Run job again
*RunApi* | [**run_jobs**](docs/RunApi.md#run_jobs) | **POST** /run | Run jobs
*RunApi* | [**run_now**](docs/RunApi.md#run_now) | **POST** /run/job/{jobId}/runNow | Bypass scheduling cretirias and start the job
*RunApi* | [**set_to_ok**](docs/RunApi.md#set_to_ok) | **POST** /run/job/{jobId}/setToOk | set job end status to OK
*RunApi* | [**undelete_job**](docs/RunApi.md#undelete_job) | **POST** /run/job/{jobId}/undelete | recover a mark for deletion job
*RunApi* | [**update_resource**](docs/RunApi.md#update_resource) | **POST** /run/resource/{ctm}/{name} | Update a quantitative resource.
*SamplesApi* | [**add_many_samples**](docs/SamplesApi.md#add_many_samples) | **POST** /samples/load | Upload samples file
*SamplesApi* | [**add_sample**](docs/SamplesApi.md#add_sample) | **POST** /samples | Create sample
*SamplesApi* | [**delete_sample**](docs/SamplesApi.md#delete_sample) | **DELETE** /samples/{sampleId} | Delete sample
*SamplesApi* | [**find_sample_by_id**](docs/SamplesApi.md#find_sample_by_id) | **GET** /samples/{sampleId} | Get sample
*SamplesApi* | [**get_samples**](docs/SamplesApi.md#get_samples) | **GET** /samples | Get all samples
*SessionApi* | [**do_login**](docs/SessionApi.md#do_login) | **POST** /session/login | login user to Control-M
*SessionApi* | [**do_logout**](docs/SessionApi.md#do_logout) | **POST** /session/logout | logout user from Control-M
*SessionApi* | [**update_my_password**](docs/SessionApi.md#update_my_password) | **POST** /session/user/password/update | Change my password


## Documentation For Models

 - [AddAgentParams](docs/AddAgentParams.md)
 - [AddRemoteHostParams](docs/AddRemoteHostParams.md)
 - [AddRemoveSuccessData](docs/AddRemoveSuccessData.md)
 - [AddServerParams](docs/AddServerParams.md)
 - [AgentDetails](docs/AgentDetails.md)
 - [AgentDetailsList](docs/AgentDetailsList.md)
 - [AgentInGroupParams](docs/AgentInGroupParams.md)
 - [AgentsInGroupListResult](docs/AgentsInGroupListResult.md)
 - [AgentsInGroupSuccessData](docs/AgentsInGroupSuccessData.md)
 - [AllowedJobActions](docs/AllowedJobActions.md)
 - [AllowedJobs](docs/AllowedJobs.md)
 - [ArchiveJobsList](docs/ArchiveJobsList.md)
 - [ArchiveRulesList](docs/ArchiveRulesList.md)
 - [AssociateData](docs/AssociateData.md)
 - [AuthenticationData](docs/AuthenticationData.md)
 - [ClientAccessPrivilegeCategory](docs/ClientAccessPrivilegeCategory.md)
 - [ConfigurationManagerPrivilegeCategory](docs/ConfigurationManagerPrivilegeCategory.md)
 - [ControlMAuthenticationData](docs/ControlMAuthenticationData.md)
 - [CtmDetails](docs/CtmDetails.md)
 - [CtmDetailsList](docs/CtmDetailsList.md)
 - [DeploymentFileError](docs/DeploymentFileError.md)
 - [DeploymentFileResults](docs/DeploymentFileResults.md)
 - [ErrorData](docs/ErrorData.md)
 - [ErrorList](docs/ErrorList.md)
 - [Event](docs/Event.md)
 - [EventParam](docs/EventParam.md)
 - [EventSet](docs/EventSet.md)
 - [ExternalProviderAuthenticationData](docs/ExternalProviderAuthenticationData.md)
 - [FolderAuth](docs/FolderAuth.md)
 - [HostgroupAgentParticipation](docs/HostgroupAgentParticipation.md)
 - [Job](docs/Job.md)
 - [JobLevelAuth](docs/JobLevelAuth.md)
 - [JobRunStatus](docs/JobRunStatus.md)
 - [JobStatusResult](docs/JobStatusResult.md)
 - [KeyValue](docs/KeyValue.md)
 - [KeyValueListResult](docs/KeyValueListResult.md)
 - [LoginCredentials](docs/LoginCredentials.md)
 - [LoginResult](docs/LoginResult.md)
 - [Matching](docs/Matching.md)
 - [MonitoringPrivilegeCategory](docs/MonitoringPrivilegeCategory.md)
 - [NewSample](docs/NewSample.md)
 - [OrderFolderParameters](docs/OrderFolderParameters.md)
 - [PasswordsObject](docs/PasswordsObject.md)
 - [PingAgentParams](docs/PingAgentParams.md)
 - [PlanningPrivilegeCategory](docs/PlanningPrivilegeCategory.md)
 - [PrivilegeName](docs/PrivilegeName.md)
 - [PrivilegeNameControlm](docs/PrivilegeNameControlm.md)
 - [Privileges](docs/Privileges.md)
 - [ProvisionAdvanceParameters](docs/ProvisionAdvanceParameters.md)
 - [ReportResult](docs/ReportResult.md)
 - [ResourceMax](docs/ResourceMax.md)
 - [ResourceObj](docs/ResourceObj.md)
 - [ResourceParam](docs/ResourceParam.md)
 - [ResourceSet](docs/ResourceSet.md)
 - [RoleData](docs/RoleData.md)
 - [RoleHeader](docs/RoleHeader.md)
 - [RoleHeaderList](docs/RoleHeaderList.md)
 - [Rule](docs/Rule.md)
 - [RuleCriteria](docs/RuleCriteria.md)
 - [RunAsUserData](docs/RunAsUserData.md)
 - [RunAsUserDetailsData](docs/RunAsUserDetailsData.md)
 - [RunAsUserKeyData](docs/RunAsUserKeyData.md)
 - [RunAsUsersList](docs/RunAsUsersList.md)
 - [RunReport](docs/RunReport.md)
 - [RunReportInfo](docs/RunReportInfo.md)
 - [RunResult](docs/RunResult.md)
 - [RunasUserAuth](docs/RunasUserAuth.md)
 - [Sample](docs/Sample.md)
 - [SamplesLoadData](docs/SamplesLoadData.md)
 - [SearchParams](docs/SearchParams.md)
 - [SecretKeyValue](docs/SecretKeyValue.md)
 - [SecretValue](docs/SecretValue.md)
 - [ServiceAuth](docs/ServiceAuth.md)
 - [ServiceAuthAction](docs/ServiceAuthAction.md)
 - [StringListResult](docs/StringListResult.md)
 - [SuccessData](docs/SuccessData.md)
 - [TermGroup](docs/TermGroup.md)
 - [ToolsPrivilegeCategory](docs/ToolsPrivilegeCategory.md)
 - [UpgradeAgentInfo](docs/UpgradeAgentInfo.md)
 - [UpgradeAgentInfoList](docs/UpgradeAgentInfoList.md)
 - [UpgradeInfo](docs/UpgradeInfo.md)
 - [UpgradeRecord](docs/UpgradeRecord.md)
 - [UpgradeRecordList](docs/UpgradeRecordList.md)
 - [UpgradeRequest](docs/UpgradeRequest.md)
 - [UpgradeResponse](docs/UpgradeResponse.md)
 - [UserData](docs/UserData.md)
 - [UserHeader](docs/UserHeader.md)
 - [UserPassword](docs/UserPassword.md)
 - [Value](docs/Value.md)
 - [ViewpointManagerPrivilegeCategory](docs/ViewpointManagerPrivilegeCategory.md)
 - [WorkloadPolicy](docs/WorkloadPolicy.md)
 - [WorkloadPolicyList](docs/WorkloadPolicyList.md)
 - [WorkloadPolicyState](docs/WorkloadPolicyState.md)
 - [WorkloadPolicyStateList](docs/WorkloadPolicyStateList.md)


## Documentation For Authorization


## Bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@bmc.com

